@@ -23,7 +23,7 @@ def conc2csv(file, word, idx):
     :param idx: index parametresi
     :param file: concordance aranacak dosya adı
     :param word: concordance aranacak sözcük
-    :return: csv (excel dosyası)
+    :return: csv (csv dosyası)
     """
     textlist = Concordance(file, word)
     data = []
@@ -33,6 +33,9 @@ def conc2csv(file, word, idx):
         after = [n for n in i[2]][:idx]  # concordance arancak sözcükten sonraki dört sözcük
         all_together = before, conc_word, after
         data.append(all_together)
+    # timestr = time.strftime("%Y%m%d-%H%M%S")
+    # output_path= str(timestr + ".csv")
+    output_path= 'data.csv'
     df = pd.DataFrame(data, columns=['before', 'conc_word', 'after'])
-    return df.to_csv('data.csv', encoding='utf-8-sig', sep=";")
+    return df.to_csv(output_path, mode='a+', encoding='utf-8-sig', sep=";")
 
